@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: ProcWait.cc,v 1.15 2002/07/17 15:10:18 lav Exp $ */
+/* $Id: ProcWait.cc,v 1.15.2.1 2004/01/14 08:22:01 lav Exp $ */
 
 #include <config.h>
 #include <sys/wait.h>
@@ -49,8 +49,6 @@ int ProcWait::Do()
    {
       if(status!=RUNNING)
 	 return MOVED;
-      if(NonFatalError(errno))
-	 goto leave;
       // waitpid failed, check the process existence
       if(kill(pid,0)==-1)
       {
