@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: commands.cc,v 1.195.2.1 2003/12/17 09:52:53 lav Exp $ */
+/* $Id: commands.cc,v 1.195.2.2 2004/01/14 11:58:03 lav Exp $ */
 
 #include <config.h>
 
@@ -2843,9 +2843,10 @@ CMD(chmod)
    if(modeind == 0)
       modeind = args->getindex();
 
-   char *arg = alloca_strdup(args->getarg(modeind));
+   const char *arg = args->getarg(modeind);
    if(!arg)
       goto usage;
+   arg = alloca_strdup(arg);
    args->delarg(modeind);
 
    if(!args->getcurr())
